#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TargetInfo import TargetInfo


class AlipayMerchantTradecomplainBatchqueryModel(object):

    def __init__(self):
        self._begin_time = None
        self._end_time = None
        self._page_num = None
        self._page_size = None
        self._status = None
        self._target_infos = None

    @property
    def begin_time(self):
        return self._begin_time

    @begin_time.setter
    def begin_time(self, value):
        self._begin_time = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def target_infos(self):
        return self._target_infos

    @target_infos.setter
    def target_infos(self, value):
        if isinstance(value, list):
            self._target_infos = list()
            for i in value:
                if isinstance(i, TargetInfo):
                    self._target_infos.append(i)
                else:
                    self._target_infos.append(TargetInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.begin_time:
            if hasattr(self.begin_time, 'to_alipay_dict'):
                params['begin_time'] = self.begin_time.to_alipay_dict()
            else:
                params['begin_time'] = self.begin_time
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.target_infos:
            if isinstance(self.target_infos, list):
                for i in range(0, len(self.target_infos)):
                    element = self.target_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.target_infos[i] = element.to_alipay_dict()
            if hasattr(self.target_infos, 'to_alipay_dict'):
                params['target_infos'] = self.target_infos.to_alipay_dict()
            else:
                params['target_infos'] = self.target_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantTradecomplainBatchqueryModel()
        if 'begin_time' in d:
            o.begin_time = d['begin_time']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'status' in d:
            o.status = d['status']
        if 'target_infos' in d:
            o.target_infos = d['target_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PointRankingInfo import PointRankingInfo


class AlipayCommerceOperationPromoterRankingQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationPromoterRankingQueryResponse, self).__init__()
        self._ranking_info = None

    @property
    def ranking_info(self):
        return self._ranking_info

    @ranking_info.setter
    def ranking_info(self, value):
        if isinstance(value, PointRankingInfo):
            self._ranking_info = value
        else:
            self._ranking_info = PointRankingInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationPromoterRankingQueryResponse, self).parse_response_content(response_content)
        if 'ranking_info' in response:
            self.ranking_info = response['ranking_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CampBaseDto import CampBaseDto


class KoubeiMarketingCampaignActivityBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignActivityBatchqueryResponse, self).__init__()
        self._camp_sets = None
        self._total_number = None

    @property
    def camp_sets(self):
        return self._camp_sets

    @camp_sets.setter
    def camp_sets(self, value):
        if isinstance(value, list):
            self._camp_sets = list()
            for i in value:
                if isinstance(i, CampBaseDto):
                    self._camp_sets.append(i)
                else:
                    self._camp_sets.append(CampBaseDto.from_alipay_dict(i))
    @property
    def total_number(self):
        return self._total_number

    @total_number.setter
    def total_number(self, value):
        self._total_number = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignActivityBatchqueryResponse, self).parse_response_content(response_content)
        if 'camp_sets' in response:
            self.camp_sets = response['camp_sets']
        if 'total_number' in response:
            self.total_number = response['total_number']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MerchantActivityVoucherInfo import MerchantActivityVoucherInfo


class MerchantOnlineActivityOpenModel(object):

    def __init__(self):
        self._activity_id = None
        self._camp_id = None
        self._count_limit = None
        self._count_limit_per_day = None
        self._count_limit_per_user = None
        self._count_limit_per_user_per_day = None
        self._crowd = None
        self._deduct_amount = None
        self._external_unique_id = None
        self._gmt_end = None
        self._gmt_start = None
        self._item_ids = None
        self._memo = None
        self._min_cost = None
        self._obtain_manually = None
        self._voucher_info = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def count_limit(self):
        return self._count_limit

    @count_limit.setter
    def count_limit(self, value):
        self._count_limit = value
    @property
    def count_limit_per_day(self):
        return self._count_limit_per_day

    @count_limit_per_day.setter
    def count_limit_per_day(self, value):
        self._count_limit_per_day = value
    @property
    def count_limit_per_user(self):
        return self._count_limit_per_user

    @count_limit_per_user.setter
    def count_limit_per_user(self, value):
        self._count_limit_per_user = value
    @property
    def count_limit_per_user_per_day(self):
        return self._count_limit_per_user_per_day

    @count_limit_per_user_per_day.setter
    def count_limit_per_user_per_day(self, value):
        self._count_limit_per_user_per_day = value
    @property
    def crowd(self):
        return self._crowd

    @crowd.setter
    def crowd(self, value):
        self._crowd = value
    @property
    def deduct_amount(self):
        return self._deduct_amount

    @deduct_amount.setter
    def deduct_amount(self, value):
        self._deduct_amount = value
    @property
    def external_unique_id(self):
        return self._external_unique_id

    @external_unique_id.setter
    def external_unique_id(self, value):
        self._external_unique_id = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def item_ids(self):
        return self._item_ids

    @item_ids.setter
    def item_ids(self, value):
        if isinstance(value, list):
            self._item_ids = list()
            for i in value:
                self._item_ids.append(i)
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def min_cost(self):
        return self._min_cost

    @min_cost.setter
    def min_cost(self, value):
        self._min_cost = value
    @property
    def obtain_manually(self):
        return self._obtain_manually

    @obtain_manually.setter
    def obtain_manually(self, value):
        self._obtain_manually = value
    @property
    def voucher_info(self):
        return self._voucher_info

    @voucher_info.setter
    def voucher_info(self, value):
        if isinstance(value, MerchantActivityVoucherInfo):
            self._voucher_info = value
        else:
            self._voucher_info = MerchantActivityVoucherInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.count_limit:
            if hasattr(self.count_limit, 'to_alipay_dict'):
                params['count_limit'] = self.count_limit.to_alipay_dict()
            else:
                params['count_limit'] = self.count_limit
        if self.count_limit_per_day:
            if hasattr(self.count_limit_per_day, 'to_alipay_dict'):
                params['count_limit_per_day'] = self.count_limit_per_day.to_alipay_dict()
            else:
                params['count_limit_per_day'] = self.count_limit_per_day
        if self.count_limit_per_user:
            if hasattr(self.count_limit_per_user, 'to_alipay_dict'):
                params['count_limit_per_user'] = self.count_limit_per_user.to_alipay_dict()
            else:
                params['count_limit_per_user'] = self.count_limit_per_user
        if self.count_limit_per_user_per_day:
            if hasattr(self.count_limit_per_user_per_day, 'to_alipay_dict'):
                params['count_limit_per_user_per_day'] = self.count_limit_per_user_per_day.to_alipay_dict()
            else:
                params['count_limit_per_user_per_day'] = self.count_limit_per_user_per_day
        if self.crowd:
            if hasattr(self.crowd, 'to_alipay_dict'):
                params['crowd'] = self.crowd.to_alipay_dict()
            else:
                params['crowd'] = self.crowd
        if self.deduct_amount:
            if hasattr(self.deduct_amount, 'to_alipay_dict'):
                params['deduct_amount'] = self.deduct_amount.to_alipay_dict()
            else:
                params['deduct_amount'] = self.deduct_amount
        if self.external_unique_id:
            if hasattr(self.external_unique_id, 'to_alipay_dict'):
                params['external_unique_id'] = self.external_unique_id.to_alipay_dict()
            else:
                params['external_unique_id'] = self.external_unique_id
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_start:
            if hasattr(self.gmt_start, 'to_alipay_dict'):
                params['gmt_start'] = self.gmt_start.to_alipay_dict()
            else:
                params['gmt_start'] = self.gmt_start
        if self.item_ids:
            if isinstance(self.item_ids, list):
                for i in range(0, len(self.item_ids)):
                    element = self.item_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_ids[i] = element.to_alipay_dict()
            if hasattr(self.item_ids, 'to_alipay_dict'):
                params['item_ids'] = self.item_ids.to_alipay_dict()
            else:
                params['item_ids'] = self.item_ids
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.min_cost:
            if hasattr(self.min_cost, 'to_alipay_dict'):
                params['min_cost'] = self.min_cost.to_alipay_dict()
            else:
                params['min_cost'] = self.min_cost
        if self.obtain_manually:
            if hasattr(self.obtain_manually, 'to_alipay_dict'):
                params['obtain_manually'] = self.obtain_manually.to_alipay_dict()
            else:
                params['obtain_manually'] = self.obtain_manually
        if self.voucher_info:
            if hasattr(self.voucher_info, 'to_alipay_dict'):
                params['voucher_info'] = self.voucher_info.to_alipay_dict()
            else:
                params['voucher_info'] = self.voucher_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantOnlineActivityOpenModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'count_limit' in d:
            o.count_limit = d['count_limit']
        if 'count_limit_per_day' in d:
            o.count_limit_per_day = d['count_limit_per_day']
        if 'count_limit_per_user' in d:
            o.count_limit_per_user = d['count_limit_per_user']
        if 'count_limit_per_user_per_day' in d:
            o.count_limit_per_user_per_day = d['count_limit_per_user_per_day']
        if 'crowd' in d:
            o.crowd = d['crowd']
        if 'deduct_amount' in d:
            o.deduct_amount = d['deduct_amount']
        if 'external_unique_id' in d:
            o.external_unique_id = d['external_unique_id']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_start' in d:
            o.gmt_start = d['gmt_start']
        if 'item_ids' in d:
            o.item_ids = d['item_ids']
        if 'memo' in d:
            o.memo = d['memo']
        if 'min_cost' in d:
            o.min_cost = d['min_cost']
        if 'obtain_manually' in d:
            o.obtain_manually = d['obtain_manually']
        if 'voucher_info' in d:
            o.voucher_info = d['voucher_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EnterprisePayInfo(object):

    def __init__(self):
        self._biz_info = None
        self._invoice_amount = None
        self._is_use_enterprise_pay = None

    @property
    def biz_info(self):
        return self._biz_info

    @biz_info.setter
    def biz_info(self, value):
        self._biz_info = value
    @property
    def invoice_amount(self):
        return self._invoice_amount

    @invoice_amount.setter
    def invoice_amount(self, value):
        self._invoice_amount = value
    @property
    def is_use_enterprise_pay(self):
        return self._is_use_enterprise_pay

    @is_use_enterprise_pay.setter
    def is_use_enterprise_pay(self, value):
        self._is_use_enterprise_pay = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_info:
            if hasattr(self.biz_info, 'to_alipay_dict'):
                params['biz_info'] = self.biz_info.to_alipay_dict()
            else:
                params['biz_info'] = self.biz_info
        if self.invoice_amount:
            if hasattr(self.invoice_amount, 'to_alipay_dict'):
                params['invoice_amount'] = self.invoice_amount.to_alipay_dict()
            else:
                params['invoice_amount'] = self.invoice_amount
        if self.is_use_enterprise_pay:
            if hasattr(self.is_use_enterprise_pay, 'to_alipay_dict'):
                params['is_use_enterprise_pay'] = self.is_use_enterprise_pay.to_alipay_dict()
            else:
                params['is_use_enterprise_pay'] = self.is_use_enterprise_pay
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EnterprisePayInfo()
        if 'biz_info' in d:
            o.biz_info = d['biz_info']
        if 'invoice_amount' in d:
            o.invoice_amount = d['invoice_amount']
        if 'is_use_enterprise_pay' in d:
            o.is_use_enterprise_pay = d['is_use_enterprise_pay']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenInstantdeliveryMerchantshopModifyModel(object):

    def __init__(self):
        self._contact_name = None
        self._logistics_codes = None
        self._out_biz_no = None
        self._phone = None
        self._shop_no = None

    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def logistics_codes(self):
        return self._logistics_codes

    @logistics_codes.setter
    def logistics_codes(self, value):
        if isinstance(value, list):
            self._logistics_codes = list()
            for i in value:
                self._logistics_codes.append(i)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def shop_no(self):
        return self._shop_no

    @shop_no.setter
    def shop_no(self, value):
        self._shop_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.logistics_codes:
            if isinstance(self.logistics_codes, list):
                for i in range(0, len(self.logistics_codes)):
                    element = self.logistics_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.logistics_codes[i] = element.to_alipay_dict()
            if hasattr(self.logistics_codes, 'to_alipay_dict'):
                params['logistics_codes'] = self.logistics_codes.to_alipay_dict()
            else:
                params['logistics_codes'] = self.logistics_codes
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.shop_no:
            if hasattr(self.shop_no, 'to_alipay_dict'):
                params['shop_no'] = self.shop_no.to_alipay_dict()
            else:
                params['shop_no'] = self.shop_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenInstantdeliveryMerchantshopModifyModel()
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'logistics_codes' in d:
            o.logistics_codes = d['logistics_codes']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'phone' in d:
            o.phone = d['phone']
        if 'shop_no' in d:
            o.shop_no = d['shop_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RecipientInfoOrder import RecipientInfoOrder


class UserInvoiceInfoOrder(object):

    def __init__(self):
        self._address = None
        self._bank_account = None
        self._bank_name = None
        self._company_name = None
        self._ip_role_id = None
        self._recipient_info = None
        self._tax_no = None
        self._telephone = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def bank_account(self):
        return self._bank_account

    @bank_account.setter
    def bank_account(self, value):
        self._bank_account = value
    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def recipient_info(self):
        return self._recipient_info

    @recipient_info.setter
    def recipient_info(self, value):
        if isinstance(value, RecipientInfoOrder):
            self._recipient_info = value
        else:
            self._recipient_info = RecipientInfoOrder.from_alipay_dict(value)
    @property
    def tax_no(self):
        return self._tax_no

    @tax_no.setter
    def tax_no(self, value):
        self._tax_no = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.bank_account:
            if hasattr(self.bank_account, 'to_alipay_dict'):
                params['bank_account'] = self.bank_account.to_alipay_dict()
            else:
                params['bank_account'] = self.bank_account
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.recipient_info:
            if hasattr(self.recipient_info, 'to_alipay_dict'):
                params['recipient_info'] = self.recipient_info.to_alipay_dict()
            else:
                params['recipient_info'] = self.recipient_info
        if self.tax_no:
            if hasattr(self.tax_no, 'to_alipay_dict'):
                params['tax_no'] = self.tax_no.to_alipay_dict()
            else:
                params['tax_no'] = self.tax_no
        if self.telephone:
            if hasattr(self.telephone, 'to_alipay_dict'):
                params['telephone'] = self.telephone.to_alipay_dict()
            else:
                params['telephone'] = self.telephone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserInvoiceInfoOrder()
        if 'address' in d:
            o.address = d['address']
        if 'bank_account' in d:
            o.bank_account = d['bank_account']
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'recipient_info' in d:
            o.recipient_info = d['recipient_info']
        if 'tax_no' in d:
            o.tax_no = d['tax_no']
        if 'telephone' in d:
            o.telephone = d['telephone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SimpleShopModel import SimpleShopModel


class KoubeiMerchantDepartmentDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMerchantDepartmentDetailQueryResponse, self).__init__()
        self._dept_id = None
        self._dept_name = None
        self._label_code = None
        self._parent_dept_id = None
        self._shops = None
        self._type = None

    @property
    def dept_id(self):
        return self._dept_id

    @dept_id.setter
    def dept_id(self, value):
        self._dept_id = value
    @property
    def dept_name(self):
        return self._dept_name

    @dept_name.setter
    def dept_name(self, value):
        self._dept_name = value
    @property
    def label_code(self):
        return self._label_code

    @label_code.setter
    def label_code(self, value):
        self._label_code = value
    @property
    def parent_dept_id(self):
        return self._parent_dept_id

    @parent_dept_id.setter
    def parent_dept_id(self, value):
        self._parent_dept_id = value
    @property
    def shops(self):
        return self._shops

    @shops.setter
    def shops(self, value):
        if isinstance(value, list):
            self._shops = list()
            for i in value:
                if isinstance(i, SimpleShopModel):
                    self._shops.append(i)
                else:
                    self._shops.append(SimpleShopModel.from_alipay_dict(i))
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMerchantDepartmentDetailQueryResponse, self).parse_response_content(response_content)
        if 'dept_id' in response:
            self.dept_id = response['dept_id']
        if 'dept_name' in response:
            self.dept_name = response['dept_name']
        if 'label_code' in response:
            self.label_code = response['label_code']
        if 'parent_dept_id' in response:
            self.parent_dept_id = response['parent_dept_id']
        if 'shops' in response:
            self.shops = response['shops']
        if 'type' in response:
            self.type = response['type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsVO(object):

    def __init__(self):
        self._addition_desc = None
        self._barcode = None
        self._biz_status = None
        self._box_num = None
        self._cainiao_item_code = None
        self._category = None
        self._category_id = None
        self._goods_code = None
        self._goods_name = None
        self._last_operate_time = None
        self._last_operator = None
        self._origin_price = None
        self._price = None
        self._produce_price = None
        self._producer_id = None
        self._producer_name = None
        self._sale_limit = None
        self._specifications = None
        self._storage_time = None
        self._supplier_id = None
        self._tax_rate = None

    @property
    def addition_desc(self):
        return self._addition_desc

    @addition_desc.setter
    def addition_desc(self, value):
        self._addition_desc = value
    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def biz_status(self):
        return self._biz_status

    @biz_status.setter
    def biz_status(self, value):
        self._biz_status = value
    @property
    def box_num(self):
        return self._box_num

    @box_num.setter
    def box_num(self, value):
        self._box_num = value
    @property
    def cainiao_item_code(self):
        return self._cainiao_item_code

    @cainiao_item_code.setter
    def cainiao_item_code(self, value):
        self._cainiao_item_code = value
    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def goods_code(self):
        return self._goods_code

    @goods_code.setter
    def goods_code(self, value):
        self._goods_code = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def last_operate_time(self):
        return self._last_operate_time

    @last_operate_time.setter
    def last_operate_time(self, value):
        self._last_operate_time = value
    @property
    def last_operator(self):
        return self._last_operator

    @last_operator.setter
    def last_operator(self, value):
        self._last_operator = value
    @property
    def origin_price(self):
        return self._origin_price

    @origin_price.setter
    def origin_price(self, value):
        self._origin_price = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def produce_price(self):
        return self._produce_price

    @produce_price.setter
    def produce_price(self, value):
        self._produce_price = value
    @property
    def producer_id(self):
        return self._producer_id

    @producer_id.setter
    def producer_id(self, value):
        self._producer_id = value
    @property
    def producer_name(self):
        return self._producer_name

    @producer_name.setter
    def producer_name(self, value):
        self._producer_name = value
    @property
    def sale_limit(self):
        return self._sale_limit

    @sale_limit.setter
    def sale_limit(self, value):
        self._sale_limit = value
    @property
    def specifications(self):
        return self._specifications

    @specifications.setter
    def specifications(self, value):
        self._specifications = value
    @property
    def storage_time(self):
        return self._storage_time

    @storage_time.setter
    def storage_time(self, value):
        self._storage_time = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value


    def to_alipay_dict(self):
        params = dict()
        if self.addition_desc:
            if hasattr(self.addition_desc, 'to_alipay_dict'):
                params['addition_desc'] = self.addition_desc.to_alipay_dict()
            else:
                params['addition_desc'] = self.addition_desc
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        if self.biz_status:
            if hasattr(self.biz_status, 'to_alipay_dict'):
                params['biz_status'] = self.biz_status.to_alipay_dict()
            else:
                params['biz_status'] = self.biz_status
        if self.box_num:
            if hasattr(self.box_num, 'to_alipay_dict'):
                params['box_num'] = self.box_num.to_alipay_dict()
            else:
                params['box_num'] = self.box_num
        if self.cainiao_item_code:
            if hasattr(self.cainiao_item_code, 'to_alipay_dict'):
                params['cainiao_item_code'] = self.cainiao_item_code.to_alipay_dict()
            else:
                params['cainiao_item_code'] = self.cainiao_item_code
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.goods_code:
            if hasattr(self.goods_code, 'to_alipay_dict'):
                params['goods_code'] = self.goods_code.to_alipay_dict()
            else:
                params['goods_code'] = self.goods_code
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.last_operate_time:
            if hasattr(self.last_operate_time, 'to_alipay_dict'):
                params['last_operate_time'] = self.last_operate_time.to_alipay_dict()
            else:
                params['last_operate_time'] = self.last_operate_time
        if self.last_operator:
            if hasattr(self.last_operator, 'to_alipay_dict'):
                params['last_operator'] = self.last_operator.to_alipay_dict()
            else:
                params['last_operator'] = self.last_operator
        if self.origin_price:
            if hasattr(self.origin_price, 'to_alipay_dict'):
                params['origin_price'] = self.origin_price.to_alipay_dict()
            else:
                params['origin_price'] = self.origin_price
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.produce_price:
            if hasattr(self.produce_price, 'to_alipay_dict'):
                params['produce_price'] = self.produce_price.to_alipay_dict()
            else:
                params['produce_price'] = self.produce_price
        if self.producer_id:
            if hasattr(self.producer_id, 'to_alipay_dict'):
                params['producer_id'] = self.producer_id.to_alipay_dict()
            else:
                params['producer_id'] = self.producer_id
        if self.producer_name:
            if hasattr(self.producer_name, 'to_alipay_dict'):
                params['producer_name'] = self.producer_name.to_alipay_dict()
            else:
                params['producer_name'] = self.producer_name
        if self.sale_limit:
            if hasattr(self.sale_limit, 'to_alipay_dict'):
                params['sale_limit'] = self.sale_limit.to_alipay_dict()
            else:
                params['sale_limit'] = self.sale_limit
        if self.specifications:
            if hasattr(self.specifications, 'to_alipay_dict'):
                params['specifications'] = self.specifications.to_alipay_dict()
            else:
                params['specifications'] = self.specifications
        if self.storage_time:
            if hasattr(self.storage_time, 'to_alipay_dict'):
                params['storage_time'] = self.storage_time.to_alipay_dict()
            else:
                params['storage_time'] = self.storage_time
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsVO()
        if 'addition_desc' in d:
            o.addition_desc = d['addition_desc']
        if 'barcode' in d:
            o.barcode = d['barcode']
        if 'biz_status' in d:
            o.biz_status = d['biz_status']
        if 'box_num' in d:
            o.box_num = d['box_num']
        if 'cainiao_item_code' in d:
            o.cainiao_item_code = d['cainiao_item_code']
        if 'category' in d:
            o.category = d['category']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'goods_code' in d:
            o.goods_code = d['goods_code']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'last_operate_time' in d:
            o.last_operate_time = d['last_operate_time']
        if 'last_operator' in d:
            o.last_operator = d['last_operator']
        if 'origin_price' in d:
            o.origin_price = d['origin_price']
        if 'price' in d:
            o.price = d['price']
        if 'produce_price' in d:
            o.produce_price = d['produce_price']
        if 'producer_id' in d:
            o.producer_id = d['producer_id']
        if 'producer_name' in d:
            o.producer_name = d['producer_name']
        if 'sale_limit' in d:
            o.sale_limit = d['sale_limit']
        if 'specifications' in d:
            o.specifications = d['specifications']
        if 'storage_time' in d:
            o.storage_time = d['storage_time']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherValidPeriod(object):

    def __init__(self):
        self._type = None
        self._valid_begin_time = None
        self._valid_days_after_receive = None
        self._valid_end_time = None
        self._wait_days_after_receive = None

    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def valid_begin_time(self):
        return self._valid_begin_time

    @valid_begin_time.setter
    def valid_begin_time(self, value):
        self._valid_begin_time = value
    @property
    def valid_days_after_receive(self):
        return self._valid_days_after_receive

    @valid_days_after_receive.setter
    def valid_days_after_receive(self, value):
        self._valid_days_after_receive = value
    @property
    def valid_end_time(self):
        return self._valid_end_time

    @valid_end_time.setter
    def valid_end_time(self, value):
        self._valid_end_time = value
    @property
    def wait_days_after_receive(self):
        return self._wait_days_after_receive

    @wait_days_after_receive.setter
    def wait_days_after_receive(self, value):
        self._wait_days_after_receive = value


    def to_alipay_dict(self):
        params = dict()
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.valid_begin_time:
            if hasattr(self.valid_begin_time, 'to_alipay_dict'):
                params['valid_begin_time'] = self.valid_begin_time.to_alipay_dict()
            else:
                params['valid_begin_time'] = self.valid_begin_time
        if self.valid_days_after_receive:
            if hasattr(self.valid_days_after_receive, 'to_alipay_dict'):
                params['valid_days_after_receive'] = self.valid_days_after_receive.to_alipay_dict()
            else:
                params['valid_days_after_receive'] = self.valid_days_after_receive
        if self.valid_end_time:
            if hasattr(self.valid_end_time, 'to_alipay_dict'):
                params['valid_end_time'] = self.valid_end_time.to_alipay_dict()
            else:
                params['valid_end_time'] = self.valid_end_time
        if self.wait_days_after_receive:
            if hasattr(self.wait_days_after_receive, 'to_alipay_dict'):
                params['wait_days_after_receive'] = self.wait_days_after_receive.to_alipay_dict()
            else:
                params['wait_days_after_receive'] = self.wait_days_after_receive
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherValidPeriod()
        if 'type' in d:
            o.type = d['type']
        if 'valid_begin_time' in d:
            o.valid_begin_time = d['valid_begin_time']
        if 'valid_days_after_receive' in d:
            o.valid_days_after_receive = d['valid_days_after_receive']
        if 'valid_end_time' in d:
            o.valid_end_time = d['valid_end_time']
        if 'wait_days_after_receive' in d:
            o.wait_days_after_receive = d['wait_days_after_receive']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class InvoiceApplyOpenApi(object):

    def __init__(self):
        self._amount = None
        self._arrangement_no = None
        self._duty_free_type = None
        self._inst_id = None
        self._invoice_date = None
        self._invoice_product_name = None
        self._invoice_specification = None
        self._ip_id = None
        self._ip_role_id = None
        self._out_biz_no = None
        self._out_biz_type = None
        self._product_code = None
        self._service_mth = None
        self._tax_rate = None
        self._tax_type = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._amount = value
        else:
            self._amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value
    @property
    def duty_free_type(self):
        return self._duty_free_type

    @duty_free_type.setter
    def duty_free_type(self, value):
        self._duty_free_type = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_product_name(self):
        return self._invoice_product_name

    @invoice_product_name.setter
    def invoice_product_name(self, value):
        self._invoice_product_name = value
    @property
    def invoice_specification(self):
        return self._invoice_specification

    @invoice_specification.setter
    def invoice_specification(self, value):
        self._invoice_specification = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def service_mth(self):
        return self._service_mth

    @service_mth.setter
    def service_mth(self, value):
        self._service_mth = value
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value
    @property
    def tax_type(self):
        return self._tax_type

    @tax_type.setter
    def tax_type(self, value):
        self._tax_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        if self.duty_free_type:
            if hasattr(self.duty_free_type, 'to_alipay_dict'):
                params['duty_free_type'] = self.duty_free_type.to_alipay_dict()
            else:
                params['duty_free_type'] = self.duty_free_type
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_product_name:
            if hasattr(self.invoice_product_name, 'to_alipay_dict'):
                params['invoice_product_name'] = self.invoice_product_name.to_alipay_dict()
            else:
                params['invoice_product_name'] = self.invoice_product_name
        if self.invoice_specification:
            if hasattr(self.invoice_specification, 'to_alipay_dict'):
                params['invoice_specification'] = self.invoice_specification.to_alipay_dict()
            else:
                params['invoice_specification'] = self.invoice_specification
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_biz_type:
            if hasattr(self.out_biz_type, 'to_alipay_dict'):
                params['out_biz_type'] = self.out_biz_type.to_alipay_dict()
            else:
                params['out_biz_type'] = self.out_biz_type
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.service_mth:
            if hasattr(self.service_mth, 'to_alipay_dict'):
                params['service_mth'] = self.service_mth.to_alipay_dict()
            else:
                params['service_mth'] = self.service_mth
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        if self.tax_type:
            if hasattr(self.tax_type, 'to_alipay_dict'):
                params['tax_type'] = self.tax_type.to_alipay_dict()
            else:
                params['tax_type'] = self.tax_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceApplyOpenApi()
        if 'amount' in d:
            o.amount = d['amount']
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        if 'duty_free_type' in d:
            o.duty_free_type = d['duty_free_type']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_product_name' in d:
            o.invoice_product_name = d['invoice_product_name']
        if 'invoice_specification' in d:
            o.invoice_specification = d['invoice_specification']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_biz_type' in d:
            o.out_biz_type = d['out_biz_type']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'service_mth' in d:
            o.service_mth = d['service_mth']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        if 'tax_type' in d:
            o.tax_type = d['tax_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditGuaranteeTradedrivePayModel(object):

    def __init__(self):
        self._biz_date = None
        self._order_encash_amt = None
        self._order_encash_ccy = None
        self._out_biz_no = None
        self._seller_login_id = None
        self._site = None

    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def order_encash_amt(self):
        return self._order_encash_amt

    @order_encash_amt.setter
    def order_encash_amt(self, value):
        self._order_encash_amt = value
    @property
    def order_encash_ccy(self):
        return self._order_encash_ccy

    @order_encash_ccy.setter
    def order_encash_ccy(self, value):
        self._order_encash_ccy = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def seller_login_id(self):
        return self._seller_login_id

    @seller_login_id.setter
    def seller_login_id(self, value):
        self._seller_login_id = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_date:
            if hasattr(self.biz_date, 'to_alipay_dict'):
                params['biz_date'] = self.biz_date.to_alipay_dict()
            else:
                params['biz_date'] = self.biz_date
        if self.order_encash_amt:
            if hasattr(self.order_encash_amt, 'to_alipay_dict'):
                params['order_encash_amt'] = self.order_encash_amt.to_alipay_dict()
            else:
                params['order_encash_amt'] = self.order_encash_amt
        if self.order_encash_ccy:
            if hasattr(self.order_encash_ccy, 'to_alipay_dict'):
                params['order_encash_ccy'] = self.order_encash_ccy.to_alipay_dict()
            else:
                params['order_encash_ccy'] = self.order_encash_ccy
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.seller_login_id:
            if hasattr(self.seller_login_id, 'to_alipay_dict'):
                params['seller_login_id'] = self.seller_login_id.to_alipay_dict()
            else:
                params['seller_login_id'] = self.seller_login_id
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditGuaranteeTradedrivePayModel()
        if 'biz_date' in d:
            o.biz_date = d['biz_date']
        if 'order_encash_amt' in d:
            o.order_encash_amt = d['order_encash_amt']
        if 'order_encash_ccy' in d:
            o.order_encash_ccy = d['order_encash_ccy']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'seller_login_id' in d:
            o.seller_login_id = d['seller_login_id']
        if 'site' in d:
            o.site = d['site']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExpenseVoucherInfo(object):

    def __init__(self):
        self._account_id = None
        self._consumption_date = None
        self._employee_id = None
        self._extension = None
        self._gmt_create = None
        self._gmt_modified = None
        self._industry = None
        self._is_off_set = None
        self._medium = None
        self._outer_source_id = None
        self._parent_type = None
        self._voucher_amount = None
        self._voucher_date = None
        self._voucher_id = None
        self._voucher_no = None
        self._voucher_state = None
        self._voucher_type = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def consumption_date(self):
        return self._consumption_date

    @consumption_date.setter
    def consumption_date(self, value):
        self._consumption_date = value
    @property
    def employee_id(self):
        return self._employee_id

    @employee_id.setter
    def employee_id(self, value):
        self._employee_id = value
    @property
    def extension(self):
        return self._extension

    @extension.setter
    def extension(self, value):
        self._extension = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def industry(self):
        return self._industry

    @industry.setter
    def industry(self, value):
        self._industry = value
    @property
    def is_off_set(self):
        return self._is_off_set

    @is_off_set.setter
    def is_off_set(self, value):
        self._is_off_set = value
    @property
    def medium(self):
        return self._medium

    @medium.setter
    def medium(self, value):
        self._medium = value
    @property
    def outer_source_id(self):
        return self._outer_source_id

    @outer_source_id.setter
    def outer_source_id(self, value):
        self._outer_source_id = value
    @property
    def parent_type(self):
        return self._parent_type

    @parent_type.setter
    def parent_type(self, value):
        self._parent_type = value
    @property
    def voucher_amount(self):
        return self._voucher_amount

    @voucher_amount.setter
    def voucher_amount(self, value):
        self._voucher_amount = value
    @property
    def voucher_date(self):
        return self._voucher_date

    @voucher_date.setter
    def voucher_date(self, value):
        self._voucher_date = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_no(self):
        return self._voucher_no

    @voucher_no.setter
    def voucher_no(self, value):
        self._voucher_no = value
    @property
    def voucher_state(self):
        return self._voucher_state

    @voucher_state.setter
    def voucher_state(self, value):
        self._voucher_state = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.consumption_date:
            if hasattr(self.consumption_date, 'to_alipay_dict'):
                params['consumption_date'] = self.consumption_date.to_alipay_dict()
            else:
                params['consumption_date'] = self.consumption_date
        if self.employee_id:
            if hasattr(self.employee_id, 'to_alipay_dict'):
                params['employee_id'] = self.employee_id.to_alipay_dict()
            else:
                params['employee_id'] = self.employee_id
        if self.extension:
            if hasattr(self.extension, 'to_alipay_dict'):
                params['extension'] = self.extension.to_alipay_dict()
            else:
                params['extension'] = self.extension
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.industry:
            if hasattr(self.industry, 'to_alipay_dict'):
                params['industry'] = self.industry.to_alipay_dict()
            else:
                params['industry'] = self.industry
        if self.is_off_set:
            if hasattr(self.is_off_set, 'to_alipay_dict'):
                params['is_off_set'] = self.is_off_set.to_alipay_dict()
            else:
                params['is_off_set'] = self.is_off_set
        if self.medium:
            if hasattr(self.medium, 'to_alipay_dict'):
                params['medium'] = self.medium.to_alipay_dict()
            else:
                params['medium'] = self.medium
        if self.outer_source_id:
            if hasattr(self.outer_source_id, 'to_alipay_dict'):
                params['outer_source_id'] = self.outer_source_id.to_alipay_dict()
            else:
                params['outer_source_id'] = self.outer_source_id
        if self.parent_type:
            if hasattr(self.parent_type, 'to_alipay_dict'):
                params['parent_type'] = self.parent_type.to_alipay_dict()
            else:
                params['parent_type'] = self.parent_type
        if self.voucher_amount:
            if hasattr(self.voucher_amount, 'to_alipay_dict'):
                params['voucher_amount'] = self.voucher_amount.to_alipay_dict()
            else:
                params['voucher_amount'] = self.voucher_amount
        if self.voucher_date:
            if hasattr(self.voucher_date, 'to_alipay_dict'):
                params['voucher_date'] = self.voucher_date.to_alipay_dict()
            else:
                params['voucher_date'] = self.voucher_date
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        if self.voucher_no:
            if hasattr(self.voucher_no, 'to_alipay_dict'):
                params['voucher_no'] = self.voucher_no.to_alipay_dict()
            else:
                params['voucher_no'] = self.voucher_no
        if self.voucher_state:
            if hasattr(self.voucher_state, 'to_alipay_dict'):
                params['voucher_state'] = self.voucher_state.to_alipay_dict()
            else:
                params['voucher_state'] = self.voucher_state
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExpenseVoucherInfo()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'consumption_date' in d:
            o.consumption_date = d['consumption_date']
        if 'employee_id' in d:
            o.employee_id = d['employee_id']
        if 'extension' in d:
            o.extension = d['extension']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'industry' in d:
            o.industry = d['industry']
        if 'is_off_set' in d:
            o.is_off_set = d['is_off_set']
        if 'medium' in d:
            o.medium = d['medium']
        if 'outer_source_id' in d:
            o.outer_source_id = d['outer_source_id']
        if 'parent_type' in d:
            o.parent_type = d['parent_type']
        if 'voucher_amount' in d:
            o.voucher_amount = d['voucher_amount']
        if 'voucher_date' in d:
            o.voucher_date = d['voucher_date']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        if 'voucher_no' in d:
            o.voucher_no = d['voucher_no']
        if 'voucher_state' in d:
            o.voucher_state = d['voucher_state']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FamilyArchiveDetail(object):

    def __init__(self):
        self._address = None
        self._archive_id = None
        self._area = None
        self._birthday = None
        self._cert_no = None
        self._cert_type = None
        self._city = None
        self._desensitized_logon_id = None
        self._desensitized_real_name = None
        self._email = None
        self._gender = None
        self._mobile = None
        self._profession = None
        self._province = None
        self._real_name = None
        self._role = None
        self._zip = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def archive_id(self):
        return self._archive_id

    @archive_id.setter
    def archive_id(self, value):
        self._archive_id = value
    @property
    def area(self):
        return self._area

    @area.setter
    def area(self, value):
        self._area = value
    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def desensitized_logon_id(self):
        return self._desensitized_logon_id

    @desensitized_logon_id.setter
    def desensitized_logon_id(self, value):
        self._desensitized_logon_id = value
    @property
    def desensitized_real_name(self):
        return self._desensitized_real_name

    @desensitized_real_name.setter
    def desensitized_real_name(self, value):
        self._desensitized_real_name = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def profession(self):
        return self._profession

    @profession.setter
    def profession(self, value):
        self._profession = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def real_name(self):
        return self._real_name

    @real_name.setter
    def real_name(self, value):
        self._real_name = value
    @property
    def role(self):
        return self._role

    @role.setter
    def role(self, value):
        self._role = value
    @property
    def zip(self):
        return self._zip

    @zip.setter
    def zip(self, value):
        self._zip = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.archive_id:
            if hasattr(self.archive_id, 'to_alipay_dict'):
                params['archive_id'] = self.archive_id.to_alipay_dict()
            else:
                params['archive_id'] = self.archive_id
        if self.area:
            if hasattr(self.area, 'to_alipay_dict'):
                params['area'] = self.area.to_alipay_dict()
            else:
                params['area'] = self.area
        if self.birthday:
            if hasattr(self.birthday, 'to_alipay_dict'):
                params['birthday'] = self.birthday.to_alipay_dict()
            else:
                params['birthday'] = self.birthday
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.desensitized_logon_id:
            if hasattr(self.desensitized_logon_id, 'to_alipay_dict'):
                params['desensitized_logon_id'] = self.desensitized_logon_id.to_alipay_dict()
            else:
                params['desensitized_logon_id'] = self.desensitized_logon_id
        if self.desensitized_real_name:
            if hasattr(self.desensitized_real_name, 'to_alipay_dict'):
                params['desensitized_real_name'] = self.desensitized_real_name.to_alipay_dict()
            else:
                params['desensitized_real_name'] = self.desensitized_real_name
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.profession:
            if hasattr(self.profession, 'to_alipay_dict'):
                params['profession'] = self.profession.to_alipay_dict()
            else:
                params['profession'] = self.profession
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.real_name:
            if hasattr(self.real_name, 'to_alipay_dict'):
                params['real_name'] = self.real_name.to_alipay_dict()
            else:
                params['real_name'] = self.real_name
        if self.role:
            if hasattr(self.role, 'to_alipay_dict'):
                params['role'] = self.role.to_alipay_dict()
            else:
                params['role'] = self.role
        if self.zip:
            if hasattr(self.zip, 'to_alipay_dict'):
                params['zip'] = self.zip.to_alipay_dict()
            else:
                params['zip'] = self.zip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FamilyArchiveDetail()
        if 'address' in d:
            o.address = d['address']
        if 'archive_id' in d:
            o.archive_id = d['archive_id']
        if 'area' in d:
            o.area = d['area']
        if 'birthday' in d:
            o.birthday = d['birthday']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'city' in d:
            o.city = d['city']
        if 'desensitized_logon_id' in d:
            o.desensitized_logon_id = d['desensitized_logon_id']
        if 'desensitized_real_name' in d:
            o.desensitized_real_name = d['desensitized_real_name']
        if 'email' in d:
            o.email = d['email']
        if 'gender' in d:
            o.gender = d['gender']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'profession' in d:
            o.profession = d['profession']
        if 'province' in d:
            o.province = d['province']
        if 'real_name' in d:
            o.real_name = d['real_name']
        if 'role' in d:
            o.role = d['role']
        if 'zip' in d:
            o.zip = d['zip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ThirdErrorContext(object):

    def __init__(self):
        self._third_error_code = None
        self._third_error_msg = None

    @property
    def third_error_code(self):
        return self._third_error_code

    @third_error_code.setter
    def third_error_code(self, value):
        self._third_error_code = value
    @property
    def third_error_msg(self):
        return self._third_error_msg

    @third_error_msg.setter
    def third_error_msg(self, value):
        self._third_error_msg = value


    def to_alipay_dict(self):
        params = dict()
        if self.third_error_code:
            if hasattr(self.third_error_code, 'to_alipay_dict'):
                params['third_error_code'] = self.third_error_code.to_alipay_dict()
            else:
                params['third_error_code'] = self.third_error_code
        if self.third_error_msg:
            if hasattr(self.third_error_msg, 'to_alipay_dict'):
                params['third_error_msg'] = self.third_error_msg.to_alipay_dict()
            else:
                params['third_error_msg'] = self.third_error_msg
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ThirdErrorContext()
        if 'third_error_code' in d:
            o.third_error_code = d['third_error_code']
        if 'third_error_msg' in d:
            o.third_error_msg = d['third_error_msg']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvoiceOrderInfo(object):

    def __init__(self):
        self._article_code = None
        self._article_fee = None
        self._article_id = None
        self._article_name = None
        self._buy_date = None
        self._end_date = None
        self._ext_json = None
        self._fact_total_fee = None
        self._invoice_kind = None
        self._item_code = None
        self._item_id = None
        self._item_name = None
        self._order_id = None
        self._order_type = None
        self._provider_key = None
        self._start_date = None
        self._tax_feature = None

    @property
    def article_code(self):
        return self._article_code

    @article_code.setter
    def article_code(self, value):
        self._article_code = value
    @property
    def article_fee(self):
        return self._article_fee

    @article_fee.setter
    def article_fee(self, value):
        self._article_fee = value
    @property
    def article_id(self):
        return self._article_id

    @article_id.setter
    def article_id(self, value):
        self._article_id = value
    @property
    def article_name(self):
        return self._article_name

    @article_name.setter
    def article_name(self, value):
        self._article_name = value
    @property
    def buy_date(self):
        return self._buy_date

    @buy_date.setter
    def buy_date(self, value):
        self._buy_date = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def ext_json(self):
        return self._ext_json

    @ext_json.setter
    def ext_json(self, value):
        self._ext_json = value
    @property
    def fact_total_fee(self):
        return self._fact_total_fee

    @fact_total_fee.setter
    def fact_total_fee(self, value):
        self._fact_total_fee = value
    @property
    def invoice_kind(self):
        return self._invoice_kind

    @invoice_kind.setter
    def invoice_kind(self, value):
        self._invoice_kind = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def provider_key(self):
        return self._provider_key

    @provider_key.setter
    def provider_key(self, value):
        self._provider_key = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def tax_feature(self):
        return self._tax_feature

    @tax_feature.setter
    def tax_feature(self, value):
        self._tax_feature = value


    def to_alipay_dict(self):
        params = dict()
        if self.article_code:
            if hasattr(self.article_code, 'to_alipay_dict'):
                params['article_code'] = self.article_code.to_alipay_dict()
            else:
                params['article_code'] = self.article_code
        if self.article_fee:
            if hasattr(self.article_fee, 'to_alipay_dict'):
                params['article_fee'] = self.article_fee.to_alipay_dict()
            else:
                params['article_fee'] = self.article_fee
        if self.article_id:
            if hasattr(self.article_id, 'to_alipay_dict'):
                params['article_id'] = self.article_id.to_alipay_dict()
            else:
                params['article_id'] = self.article_id
        if self.article_name:
            if hasattr(self.article_name, 'to_alipay_dict'):
                params['article_name'] = self.article_name.to_alipay_dict()
            else:
                params['article_name'] = self.article_name
        if self.buy_date:
            if hasattr(self.buy_date, 'to_alipay_dict'):
                params['buy_date'] = self.buy_date.to_alipay_dict()
            else:
                params['buy_date'] = self.buy_date
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.ext_json:
            if hasattr(self.ext_json, 'to_alipay_dict'):
                params['ext_json'] = self.ext_json.to_alipay_dict()
            else:
                params['ext_json'] = self.ext_json
        if self.fact_total_fee:
            if hasattr(self.fact_total_fee, 'to_alipay_dict'):
                params['fact_total_fee'] = self.fact_total_fee.to_alipay_dict()
            else:
                params['fact_total_fee'] = self.fact_total_fee
        if self.invoice_kind:
            if hasattr(self.invoice_kind, 'to_alipay_dict'):
                params['invoice_kind'] = self.invoice_kind.to_alipay_dict()
            else:
                params['invoice_kind'] = self.invoice_kind
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.provider_key:
            if hasattr(self.provider_key, 'to_alipay_dict'):
                params['provider_key'] = self.provider_key.to_alipay_dict()
            else:
                params['provider_key'] = self.provider_key
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.tax_feature:
            if hasattr(self.tax_feature, 'to_alipay_dict'):
                params['tax_feature'] = self.tax_feature.to_alipay_dict()
            else:
                params['tax_feature'] = self.tax_feature
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceOrderInfo()
        if 'article_code' in d:
            o.article_code = d['article_code']
        if 'article_fee' in d:
            o.article_fee = d['article_fee']
        if 'article_id' in d:
            o.article_id = d['article_id']
        if 'article_name' in d:
            o.article_name = d['article_name']
        if 'buy_date' in d:
            o.buy_date = d['buy_date']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'ext_json' in d:
            o.ext_json = d['ext_json']
        if 'fact_total_fee' in d:
            o.fact_total_fee = d['fact_total_fee']
        if 'invoice_kind' in d:
            o.invoice_kind = d['invoice_kind']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'provider_key' in d:
            o.provider_key = d['provider_key']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'tax_feature' in d:
            o.tax_feature = d['tax_feature']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingVoucherStockCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherStockCreateResponse, self).__init__()
        self._duplicate_count = None
        self._fail_count = None
        self._stock_id = None
        self._success_count = None

    @property
    def duplicate_count(self):
        return self._duplicate_count

    @duplicate_count.setter
    def duplicate_count(self, value):
        self._duplicate_count = value
    @property
    def fail_count(self):
        return self._fail_count

    @fail_count.setter
    def fail_count(self, value):
        self._fail_count = value
    @property
    def stock_id(self):
        return self._stock_id

    @stock_id.setter
    def stock_id(self, value):
        self._stock_id = value
    @property
    def success_count(self):
        return self._success_count

    @success_count.setter
    def success_count(self, value):
        self._success_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherStockCreateResponse, self).parse_response_content(response_content)
        if 'duplicate_count' in response:
            self.duplicate_count = response['duplicate_count']
        if 'fail_count' in response:
            self.fail_count = response['fail_count']
        if 'stock_id' in response:
            self.stock_id = response['stock_id']
        if 'success_count' in response:
            self.success_count = response['success_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarMaintainShopCreateModel(object):

    def __init__(self):
        self._address = None
        self._alipay_account = None
        self._brand_ids = None
        self._city_code = None
        self._close_time = None
        self._contact_email = None
        self._contact_mobile_phone = None
        self._contact_name = None
        self._district_code = None
        self._ext_param = None
        self._industry_app_category_id = None
        self._industry_category_id = None
        self._lat = None
        self._lon = None
        self._main_image = None
        self._merchant_branch_id = None
        self._open_time = None
        self._other_images = None
        self._out_shop_id = None
        self._province_code = None
        self._shop_branch_name = None
        self._shop_name = None
        self._shop_tel = None
        self._shop_type = None
        self._status = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def alipay_account(self):
        return self._alipay_account

    @alipay_account.setter
    def alipay_account(self, value):
        self._alipay_account = value
    @property
    def brand_ids(self):
        return self._brand_ids

    @brand_ids.setter
    def brand_ids(self, value):
        if isinstance(value, list):
            self._brand_ids = list()
            for i in value:
                self._brand_ids.append(i)
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def close_time(self):
        return self._close_time

    @close_time.setter
    def close_time(self, value):
        self._close_time = value
    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def contact_mobile_phone(self):
        return self._contact_mobile_phone

    @contact_mobile_phone.setter
    def contact_mobile_phone(self, value):
        self._contact_mobile_phone = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def industry_app_category_id(self):
        return self._industry_app_category_id

    @industry_app_category_id.setter
    def industry_app_category_id(self, value):
        if isinstance(value, list):
            self._industry_app_category_id = list()
            for i in value:
                self._industry_app_category_id.append(i)
    @property
    def industry_category_id(self):
        return self._industry_category_id

    @industry_category_id.setter
    def industry_category_id(self, value):
        if isinstance(value, list):
            self._industry_category_id = list()
            for i in value:
                self._industry_category_id.append(i)
    @property
    def lat(self):
        return self._lat

    @lat.setter
    def lat(self, value):
        self._lat = value
    @property
    def lon(self):
        return self._lon

    @lon.setter
    def lon(self, value):
        self._lon = value
    @property
    def main_image(self):
        return self._main_image

    @main_image.setter
    def main_image(self, value):
        self._main_image = value
    @property
    def merchant_branch_id(self):
        return self._merchant_branch_id

    @merchant_branch_id.setter
    def merchant_branch_id(self, value):
        self._merchant_branch_id = value
    @property
    def open_time(self):
        return self._open_time

    @open_time.setter
    def open_time(self, value):
        self._open_time = value
    @property
    def other_images(self):
        return self._other_images

    @other_images.setter
    def other_images(self, value):
        if isinstance(value, list):
            self._other_images = list()
            for i in value:
                self._other_images.append(i)
    @property
    def out_shop_id(self):
        return self._out_shop_id

    @out_shop_id.setter
    def out_shop_id(self, value):
        self._out_shop_id = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def shop_branch_name(self):
        return self._shop_branch_name

    @shop_branch_name.setter
    def shop_branch_name(self, value):
        self._shop_branch_name = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_tel(self):
        return self._shop_tel

    @shop_tel.setter
    def shop_tel(self, value):
        self._shop_tel = value
    @property
    def shop_type(self):
        return self._shop_type

    @shop_type.setter
    def shop_type(self, value):
        self._shop_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.alipay_account:
            if hasattr(self.alipay_account, 'to_alipay_dict'):
                params['alipay_account'] = self.alipay_account.to_alipay_dict()
            else:
                params['alipay_account'] = self.alipay_account
        if self.brand_ids:
            if isinstance(self.brand_ids, list):
                for i in range(0, len(self.brand_ids)):
                    element = self.brand_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.brand_ids[i] = element.to_alipay_dict()
            if hasattr(self.brand_ids, 'to_alipay_dict'):
                params['brand_ids'] = self.brand_ids.to_alipay_dict()
            else:
                params['brand_ids'] = self.brand_ids
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.close_time:
            if hasattr(self.close_time, 'to_alipay_dict'):
                params['close_time'] = self.close_time.to_alipay_dict()
            else:
                params['close_time'] = self.close_time
        if self.contact_email:
            if hasattr(self.contact_email, 'to_alipay_dict'):
                params['contact_email'] = self.contact_email.to_alipay_dict()
            else:
                params['contact_email'] = self.contact_email
        if self.contact_mobile_phone:
            if hasattr(self.contact_mobile_phone, 'to_alipay_dict'):
                params['contact_mobile_phone'] = self.contact_mobile_phone.to_alipay_dict()
            else:
                params['contact_mobile_phone'] = self.contact_mobile_phone
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.industry_app_category_id:
            if isinstance(self.industry_app_category_id, list):
                for i in range(0, len(self.industry_app_category_id)):
                    element = self.industry_app_category_id[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.industry_app_category_id[i] = element.to_alipay_dict()
            if hasattr(self.industry_app_category_id, 'to_alipay_dict'):
                params['industry_app_category_id'] = self.industry_app_category_id.to_alipay_dict()
            else:
                params['industry_app_category_id'] = self.industry_app_category_id
        if self.industry_category_id:
            if isinstance(self.industry_category_id, list):
                for i in range(0, len(self.industry_category_id)):
                    element = self.industry_category_id[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.industry_category_id[i] = element.to_alipay_dict()
            if hasattr(self.industry_category_id, 'to_alipay_dict'):
                params['industry_category_id'] = self.industry_category_id.to_alipay_dict()
            else:
                params['industry_category_id'] = self.industry_category_id
        if self.lat:
            if hasattr(self.lat, 'to_alipay_dict'):
                params['lat'] = self.lat.to_alipay_dict()
            else:
                params['lat'] = self.lat
        if self.lon:
            if hasattr(self.lon, 'to_alipay_dict'):
                params['lon'] = self.lon.to_alipay_dict()
            else:
                params['lon'] = self.lon
        if self.main_image:
            if hasattr(self.main_image, 'to_alipay_dict'):
                params['main_image'] = self.main_image.to_alipay_dict()
            else:
                params['main_image'] = self.main_image
        if self.merchant_branch_id:
            if hasattr(self.merchant_branch_id, 'to_alipay_dict'):
                params['merchant_branch_id'] = self.merchant_branch_id.to_alipay_dict()
            else:
                params['merchant_branch_id'] = self.merchant_branch_id
        if self.open_time:
            if hasattr(self.open_time, 'to_alipay_dict'):
                params['open_time'] = self.open_time.to_alipay_dict()
            else:
                params['open_time'] = self.open_time
        if self.other_images:
            if isinstance(self.other_images, list):
                for i in range(0, len(self.other_images)):
                    element = self.other_images[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.other_images[i] = element.to_alipay_dict()
            if hasattr(self.other_images, 'to_alipay_dict'):
                params['other_images'] = self.other_images.to_alipay_dict()
            else:
                params['other_images'] = self.other_images
        if self.out_shop_id:
            if hasattr(self.out_shop_id, 'to_alipay_dict'):
                params['out_shop_id'] = self.out_shop_id.to_alipay_dict()
            else:
                params['out_shop_id'] = self.out_shop_id
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.shop_branch_name:
            if hasattr(self.shop_branch_name, 'to_alipay_dict'):
                params['shop_branch_name'] = self.shop_branch_name.to_alipay_dict()
            else:
                params['shop_branch_name'] = self.shop_branch_name
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_tel:
            if hasattr(self.shop_tel, 'to_alipay_dict'):
                params['shop_tel'] = self.shop_tel.to_alipay_dict()
            else:
                params['shop_tel'] = self.shop_tel
        if self.shop_type:
            if hasattr(self.shop_type, 'to_alipay_dict'):
                params['shop_type'] = self.shop_type.to_alipay_dict()
            else:
                params['shop_type'] = self.shop_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarMaintainShopCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'alipay_account' in d:
            o.alipay_account = d['alipay_account']
        if 'brand_ids' in d:
            o.brand_ids = d['brand_ids']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'close_time' in d:
            o.close_time = d['close_time']
        if 'contact_email' in d:
            o.contact_email = d['contact_email']
        if 'contact_mobile_phone' in d:
            o.contact_mobile_phone = d['contact_mobile_phone']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'industry_app_category_id' in d:
            o.industry_app_category_id = d['industry_app_category_id']
        if 'industry_category_id' in d:
            o.industry_category_id = d['industry_category_id']
        if 'lat' in d:
            o.lat = d['lat']
        if 'lon' in d:
            o.lon = d['lon']
        if 'main_image' in d:
            o.main_image = d['main_image']
        if 'merchant_branch_id' in d:
            o.merchant_branch_id = d['merchant_branch_id']
        if 'open_time' in d:
            o.open_time = d['open_time']
        if 'other_images' in d:
            o.other_images = d['other_images']
        if 'out_shop_id' in d:
            o.out_shop_id = d['out_shop_id']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'shop_branch_name' in d:
            o.shop_branch_name = d['shop_branch_name']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_tel' in d:
            o.shop_tel = d['shop_tel']
        if 'shop_type' in d:
            o.shop_type = d['shop_type']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GeneralInvoiceItem import GeneralInvoiceItem


class AlipayEbppInvoiceOpenRedCreateModel(object):

    def __init__(self):
        self._alipay_user_id = None
        self._auto_fill_info = None
        self._auto_preprocess = None
        self._invoice_amount = None
        self._invoice_items = None
        self._invoice_kind = None
        self._invoice_memo = None
        self._invoice_type = None
        self._normal_invoice_code = None
        self._normal_invoice_no = None
        self._outer_id = None
        self._payee_address = None
        self._payee_bank_account_id = None
        self._payee_bank_name = None
        self._payee_checker = None
        self._payee_name = None
        self._payee_operator = None
        self._payee_phone = None
        self._payee_receiver = None
        self._payee_register_no = None
        self._payer_address = None
        self._payer_bank_account_id = None
        self._payer_bank_name = None
        self._payer_name = None
        self._payer_phone = None
        self._payer_register_no = None
        self._platform_code = None
        self._platform_user_id = None
        self._product_code = None
        self._sum_price = None
        self._sum_tax = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def auto_fill_info(self):
        return self._auto_fill_info

    @auto_fill_info.setter
    def auto_fill_info(self, value):
        self._auto_fill_info = value
    @property
    def auto_preprocess(self):
        return self._auto_preprocess

    @auto_preprocess.setter
    def auto_preprocess(self, value):
        self._auto_preprocess = value
    @property
    def invoice_amount(self):
        return self._invoice_amount

    @invoice_amount.setter
    def invoice_amount(self, value):
        self._invoice_amount = value
    @property
    def invoice_items(self):
        return self._invoice_items

    @invoice_items.setter
    def invoice_items(self, value):
        if isinstance(value, list):
            self._invoice_items = list()
            for i in value:
                if isinstance(i, GeneralInvoiceItem):
                    self._invoice_items.append(i)
                else:
                    self._invoice_items.append(GeneralInvoiceItem.from_alipay_dict(i))
    @property
    def invoice_kind(self):
        return self._invoice_kind

    @invoice_kind.setter
    def invoice_kind(self, value):
        self._invoice_kind = value
    @property
    def invoice_memo(self):
        return self._invoice_memo

    @invoice_memo.setter
    def invoice_memo(self, value):
        self._invoice_memo = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def normal_invoice_code(self):
        return self._normal_invoice_code

    @normal_invoice_code.setter
    def normal_invoice_code(self, value):
        self._normal_invoice_code = value
    @property
    def normal_invoice_no(self):
        return self._normal_invoice_no

    @normal_invoice_no.setter
    def normal_invoice_no(self, value):
        self._normal_invoice_no = value
    @property
    def outer_id(self):
        return self._outer_id

    @outer_id.setter
    def outer_id(self, value):
        self._outer_id = value
    @property
    def payee_address(self):
        return self._payee_address

    @payee_address.setter
    def payee_address(self, value):
        self._payee_address = value
    @property
    def payee_bank_account_id(self):
        return self._payee_bank_account_id

    @payee_bank_account_id.setter
    def payee_bank_account_id(self, value):
        self._payee_bank_account_id = value
    @property
    def payee_bank_name(self):
        return self._payee_bank_name

    @payee_bank_name.setter
    def payee_bank_name(self, value):
        self._payee_bank_name = value
    @property
    def payee_checker(self):
        return self._payee_checker

    @payee_checker.setter
    def payee_checker(self, value):
        self._payee_checker = value
    @property
    def payee_name(self):
        return self._payee_name

    @payee_name.setter
    def payee_name(self, value):
        self._payee_name = value
    @property
    def payee_operator(self):
        return self._payee_operator

    @payee_operator.setter
    def payee_operator(self, value):
        self._payee_operator = value
    @property
    def payee_phone(self):
        return self._payee_phone

    @payee_phone.setter
    def payee_phone(self, value):
        self._payee_phone = value
    @property
    def payee_receiver(self):
        return self._payee_receiver

    @payee_receiver.setter
    def payee_receiver(self, value):
        self._payee_receiver = value
    @property
    def payee_register_no(self):
        return self._payee_register_no

    @payee_register_no.setter
    def payee_register_no(self, value):
        self._payee_register_no = value
    @property
    def payer_address(self):
        return self._payer_address

    @payer_address.setter
    def payer_address(self, value):
        self._payer_address = value
    @property
    def payer_bank_account_id(self):
        return self._payer_bank_account_id

    @payer_bank_account_id.setter
    def payer_bank_account_id(self, value):
        self._payer_bank_account_id = value
    @property
    def payer_bank_name(self):
        return self._payer_bank_name

    @payer_bank_name.setter
    def payer_bank_name(self, value):
        self._payer_bank_name = value
    @property
    def payer_name(self):
        return self._payer_name

    @payer_name.setter
    def payer_name(self, value):
        self._payer_name = value
    @property
    def payer_phone(self):
        return self._payer_phone

    @payer_phone.setter
    def payer_phone(self, value):
        self._payer_phone = value
    @property
    def payer_register_no(self):
        return self._payer_register_no

    @payer_register_no.setter
    def payer_register_no(self, value):
        self._payer_register_no = value
    @property
    def platform_code(self):
        return self._platform_code

    @platform_code.setter
    def platform_code(self, value):
        self._platform_code = value
    @property
    def platform_user_id(self):
        return self._platform_user_id

    @platform_user_id.setter
    def platform_user_id(self, value):
        self._platform_user_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def sum_price(self):
        return self._sum_price

    @sum_price.setter
    def sum_price(self, value):
        self._sum_price = value
    @property
    def sum_tax(self):
        return self._sum_tax

    @sum_tax.setter
    def sum_tax(self, value):
        self._sum_tax = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.auto_fill_info:
            if hasattr(self.auto_fill_info, 'to_alipay_dict'):
                params['auto_fill_info'] = self.auto_fill_info.to_alipay_dict()
            else:
                params['auto_fill_info'] = self.auto_fill_info
        if self.auto_preprocess:
            if hasattr(self.auto_preprocess, 'to_alipay_dict'):
                params['auto_preprocess'] = self.auto_preprocess.to_alipay_dict()
            else:
                params['auto_preprocess'] = self.auto_preprocess
        if self.invoice_amount:
            if hasattr(self.invoice_amount, 'to_alipay_dict'):
                params['invoice_amount'] = self.invoice_amount.to_alipay_dict()
            else:
                params['invoice_amount'] = self.invoice_amount
        if self.invoice_items:
            if isinstance(self.invoice_items, list):
                for i in range(0, len(self.invoice_items)):
                    element = self.invoice_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invoice_items[i] = element.to_alipay_dict()
            if hasattr(self.invoice_items, 'to_alipay_dict'):
                params['invoice_items'] = self.invoice_items.to_alipay_dict()
            else:
                params['invoice_items'] = self.invoice_items
        if self.invoice_kind:
            if hasattr(self.invoice_kind, 'to_alipay_dict'):
                params['invoice_kind'] = self.invoice_kind.to_alipay_dict()
            else:
                params['invoice_kind'] = self.invoice_kind
        if self.invoice_memo:
            if hasattr(self.invoice_memo, 'to_alipay_dict'):
                params['invoice_memo'] = self.invoice_memo.to_alipay_dict()
            else:
                params['invoice_memo'] = self.invoice_memo
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.normal_invoice_code:
            if hasattr(self.normal_invoice_code, 'to_alipay_dict'):
                params['normal_invoice_code'] = self.normal_invoice_code.to_alipay_dict()
            else:
                params['normal_invoice_code'] = self.normal_invoice_code
        if self.normal_invoice_no:
            if hasattr(self.normal_invoice_no, 'to_alipay_dict'):
                params['normal_invoice_no'] = self.normal_invoice_no.to_alipay_dict()
            else:
                params['normal_invoice_no'] = self.normal_invoice_no
        if self.outer_id:
            if hasattr(self.outer_id, 'to_alipay_dict'):
                params['outer_id'] = self.outer_id.to_alipay_dict()
            else:
                params['outer_id'] = self.outer_id
        if self.payee_address:
            if hasattr(self.payee_address, 'to_alipay_dict'):
                params['payee_address'] = self.payee_address.to_alipay_dict()
            else:
                params['payee_address'] = self.payee_address
        if self.payee_bank_account_id:
            if hasattr(self.payee_bank_account_id, 'to_alipay_dict'):
                params['payee_bank_account_id'] = self.payee_bank_account_id.to_alipay_dict()
            else:
                params['payee_bank_account_id'] = self.payee_bank_account_id
        if self.payee_bank_name:
            if hasattr(self.payee_bank_name, 'to_alipay_dict'):
                params['payee_bank_name'] = self.payee_bank_name.to_alipay_dict()
            else:
                params['payee_bank_name'] = self.payee_bank_name
        if self.payee_checker:
            if hasattr(self.payee_checker, 'to_alipay_dict'):
                params['payee_checker'] = self.payee_checker.to_alipay_dict()
            else:
                params['payee_checker'] = self.payee_checker
        if self.payee_name:
            if hasattr(self.payee_name, 'to_alipay_dict'):
                params['payee_name'] = self.payee_name.to_alipay_dict()
            else:
                params['payee_name'] = self.payee_name
        if self.payee_operator:
            if hasattr(self.payee_operator, 'to_alipay_dict'):
                params['payee_operator'] = self.payee_operator.to_alipay_dict()
            else:
                params['payee_operator'] = self.payee_operator
        if self.payee_phone:
            if hasattr(self.payee_phone, 'to_alipay_dict'):
                params['payee_phone'] = self.payee_phone.to_alipay_dict()
            else:
                params['payee_phone'] = self.payee_phone
        if self.payee_receiver:
            if hasattr(self.payee_receiver, 'to_alipay_dict'):
                params['payee_receiver'] = self.payee_receiver.to_alipay_dict()
            else:
                params['payee_receiver'] = self.payee_receiver
        if self.payee_register_no:
            if hasattr(self.payee_register_no, 'to_alipay_dict'):
                params['payee_register_no'] = self.payee_register_no.to_alipay_dict()
            else:
                params['payee_register_no'] = self.payee_register_no
        if self.payer_address:
            if hasattr(self.payer_address, 'to_alipay_dict'):
                params['payer_address'] = self.payer_address.to_alipay_dict()
            else:
                params['payer_address'] = self.payer_address
        if self.payer_bank_account_id:
            if hasattr(self.payer_bank_account_id, 'to_alipay_dict'):
                params['payer_bank_account_id'] = self.payer_bank_account_id.to_alipay_dict()
            else:
                params['payer_bank_account_id'] = self.payer_bank_account_id
        if self.payer_bank_name:
            if hasattr(self.payer_bank_name, 'to_alipay_dict'):
                params['payer_bank_name'] = self.payer_bank_name.to_alipay_dict()
            else:
                params['payer_bank_name'] = self.payer_bank_name
        if self.payer_name:
            if hasattr(self.payer_name, 'to_alipay_dict'):
                params['payer_name'] = self.payer_name.to_alipay_dict()
            else:
                params['payer_name'] = self.payer_name
        if self.payer_phone:
            if hasattr(self.payer_phone, 'to_alipay_dict'):
                params['payer_phone'] = self.payer_phone.to_alipay_dict()
            else:
                params['payer_phone'] = self.payer_phone
        if self.payer_register_no:
            if hasattr(self.payer_register_no, 'to_alipay_dict'):
                params['payer_register_no'] = self.payer_register_no.to_alipay_dict()
            else:
                params['payer_register_no'] = self.payer_register_no
        if self.platform_code:
            if hasattr(self.platform_code, 'to_alipay_dict'):
                params['platform_code'] = self.platform_code.to_alipay_dict()
            else:
                params['platform_code'] = self.platform_code
        if self.platform_user_id:
            if hasattr(self.platform_user_id, 'to_alipay_dict'):
                params['platform_user_id'] = self.platform_user_id.to_alipay_dict()
            else:
                params['platform_user_id'] = self.platform_user_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.sum_price:
            if hasattr(self.sum_price, 'to_alipay_dict'):
                params['sum_price'] = self.sum_price.to_alipay_dict()
            else:
                params['sum_price'] = self.sum_price
        if self.sum_tax:
            if hasattr(self.sum_tax, 'to_alipay_dict'):
                params['sum_tax'] = self.sum_tax.to_alipay_dict()
            else:
                params['sum_tax'] = self.sum_tax
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceOpenRedCreateModel()
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'auto_fill_info' in d:
            o.auto_fill_info = d['auto_fill_info']
        if 'auto_preprocess' in d:
            o.auto_preprocess = d['auto_preprocess']
        if 'invoice_amount' in d:
            o.invoice_amount = d['invoice_amount']
        if 'invoice_items' in d:
            o.invoice_items = d['invoice_items']
        if 'invoice_kind' in d:
            o.invoice_kind = d['invoice_kind']
        if 'invoice_memo' in d:
            o.invoice_memo = d['invoice_memo']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'normal_invoice_code' in d:
            o.normal_invoice_code = d['normal_invoice_code']
        if 'normal_invoice_no' in d:
            o.normal_invoice_no = d['normal_invoice_no']
        if 'outer_id' in d:
            o.outer_id = d['outer_id']
        if 'payee_address' in d:
            o.payee_address = d['payee_address']
        if 'payee_bank_account_id' in d:
            o.payee_bank_account_id = d['payee_bank_account_id']
        if 'payee_bank_name' in d:
            o.payee_bank_name = d['payee_bank_name']
        if 'payee_checker' in d:
            o.payee_checker = d['payee_checker']
        if 'payee_name' in d:
            o.payee_name = d['payee_name']
        if 'payee_operator' in d:
            o.payee_operator = d['payee_operator']
        if 'payee_phone' in d:
            o.payee_phone = d['payee_phone']
        if 'payee_receiver' in d:
            o.payee_receiver = d['payee_receiver']
        if 'payee_register_no' in d:
            o.payee_register_no = d['payee_register_no']
        if 'payer_address' in d:
            o.payer_address = d['payer_address']
        if 'payer_bank_account_id' in d:
            o.payer_bank_account_id = d['payer_bank_account_id']
        if 'payer_bank_name' in d:
            o.payer_bank_name = d['payer_bank_name']
        if 'payer_name' in d:
            o.payer_name = d['payer_name']
        if 'payer_phone' in d:
            o.payer_phone = d['payer_phone']
        if 'payer_register_no' in d:
            o.payer_register_no = d['payer_register_no']
        if 'platform_code' in d:
            o.platform_code = d['platform_code']
        if 'platform_user_id' in d:
            o.platform_user_id = d['platform_user_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'sum_price' in d:
            o.sum_price = d['sum_price']
        if 'sum_tax' in d:
            o.sum_tax = d['sum_tax']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DishCategoryEntity import DishCategoryEntity


class KoubeiCateringPosCategorySaveModel(object):

    def __init__(self):
        self._category_entity_list = None

    @property
    def category_entity_list(self):
        return self._category_entity_list

    @category_entity_list.setter
    def category_entity_list(self, value):
        if isinstance(value, list):
            self._category_entity_list = list()
            for i in value:
                if isinstance(i, DishCategoryEntity):
                    self._category_entity_list.append(i)
                else:
                    self._category_entity_list.append(DishCategoryEntity.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.category_entity_list:
            if isinstance(self.category_entity_list, list):
                for i in range(0, len(self.category_entity_list)):
                    element = self.category_entity_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.category_entity_list[i] = element.to_alipay_dict()
            if hasattr(self.category_entity_list, 'to_alipay_dict'):
                params['category_entity_list'] = self.category_entity_list.to_alipay_dict()
            else:
                params['category_entity_list'] = self.category_entity_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosCategorySaveModel()
        if 'category_entity_list' in d:
            o.category_entity_list = d['category_entity_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdFacePayCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdFacePayCreateResponse, self).__init__()
        self._bbb = None

    @property
    def bbb(self):
        return self._bbb

    @bbb.setter
    def bbb(self, value):
        self._bbb = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdFacePayCreateResponse, self).parse_response_content(response_content)
        if 'bbb' in response:
            self.bbb = response['bbb']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeCreditApplyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeCreditApplyQueryResponse, self).__init__()
        self._buyer_credit_source = None
        self._buyer_user_id = None
        self._credit_scene = None
        self._grant_credit_quota = None
        self._grant_operation_no = None
        self._grant_status = None
        self._merchant_credit_source = None
        self._merchant_user_id = None
        self._out_request_no = None

    @property
    def buyer_credit_source(self):
        return self._buyer_credit_source

    @buyer_credit_source.setter
    def buyer_credit_source(self, value):
        self._buyer_credit_source = value
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def credit_scene(self):
        return self._credit_scene

    @credit_scene.setter
    def credit_scene(self, value):
        self._credit_scene = value
    @property
    def grant_credit_quota(self):
        return self._grant_credit_quota

    @grant_credit_quota.setter
    def grant_credit_quota(self, value):
        self._grant_credit_quota = value
    @property
    def grant_operation_no(self):
        return self._grant_operation_no

    @grant_operation_no.setter
    def grant_operation_no(self, value):
        self._grant_operation_no = value
    @property
    def grant_status(self):
        return self._grant_status

    @grant_status.setter
    def grant_status(self, value):
        self._grant_status = value
    @property
    def merchant_credit_source(self):
        return self._merchant_credit_source

    @merchant_credit_source.setter
    def merchant_credit_source(self, value):
        self._merchant_credit_source = value
    @property
    def merchant_user_id(self):
        return self._merchant_user_id

    @merchant_user_id.setter
    def merchant_user_id(self, value):
        self._merchant_user_id = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeCreditApplyQueryResponse, self).parse_response_content(response_content)
        if 'buyer_credit_source' in response:
            self.buyer_credit_source = response['buyer_credit_source']
        if 'buyer_user_id' in response:
            self.buyer_user_id = response['buyer_user_id']
        if 'credit_scene' in response:
            self.credit_scene = response['credit_scene']
        if 'grant_credit_quota' in response:
            self.grant_credit_quota = response['grant_credit_quota']
        if 'grant_operation_no' in response:
            self.grant_operation_no = response['grant_operation_no']
        if 'grant_status' in response:
            self.grant_status = response['grant_status']
        if 'merchant_credit_source' in response:
            self.merchant_credit_source = response['merchant_credit_source']
        if 'merchant_user_id' in response:
            self.merchant_user_id = response['merchant_user_id']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCcmAgentQueryModel(object):

    def __init__(self):
        self._answering_mode = None
        self._ccs_instance_id = None
        self._chat_ext_group_ids = None
        self._chat_group_ids = None
        self._chat_level_ids = None
        self._email = None
        self._hotline_group_ids = None
        self._page_num = None
        self._page_size = None
        self._real_name = None
        self._role_ids = None

    @property
    def answering_mode(self):
        return self._answering_mode

    @answering_mode.setter
    def answering_mode(self, value):
        self._answering_mode = value
    @property
    def ccs_instance_id(self):
        return self._ccs_instance_id

    @ccs_instance_id.setter
    def ccs_instance_id(self, value):
        self._ccs_instance_id = value
    @property
    def chat_ext_group_ids(self):
        return self._chat_ext_group_ids

    @chat_ext_group_ids.setter
    def chat_ext_group_ids(self, value):
        if isinstance(value, list):
            self._chat_ext_group_ids = list()
            for i in value:
                self._chat_ext_group_ids.append(i)
    @property
    def chat_group_ids(self):
        return self._chat_group_ids

    @chat_group_ids.setter
    def chat_group_ids(self, value):
        if isinstance(value, list):
            self._chat_group_ids = list()
            for i in value:
                self._chat_group_ids.append(i)
    @property
    def chat_level_ids(self):
        return self._chat_level_ids

    @chat_level_ids.setter
    def chat_level_ids(self, value):
        if isinstance(value, list):
            self._chat_level_ids = list()
            for i in value:
                self._chat_level_ids.append(i)
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def hotline_group_ids(self):
        return self._hotline_group_ids

    @hotline_group_ids.setter
    def hotline_group_ids(self, value):
        if isinstance(value, list):
            self._hotline_group_ids = list()
            for i in value:
                self._hotline_group_ids.append(i)
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def real_name(self):
        return self._real_name

    @real_name.setter
    def real_name(self, value):
        self._real_name = value
    @property
    def role_ids(self):
        return self._role_ids

    @role_ids.setter
    def role_ids(self, value):
        if isinstance(value, list):
            self._role_ids = list()
            for i in value:
                self._role_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.answering_mode:
            if hasattr(self.answering_mode, 'to_alipay_dict'):
                params['answering_mode'] = self.answering_mode.to_alipay_dict()
            else:
                params['answering_mode'] = self.answering_mode
        if self.ccs_instance_id:
            if hasattr(self.ccs_instance_id, 'to_alipay_dict'):
                params['ccs_instance_id'] = self.ccs_instance_id.to_alipay_dict()
            else:
                params['ccs_instance_id'] = self.ccs_instance_id
        if self.chat_ext_group_ids:
            if isinstance(self.chat_ext_group_ids, list):
                for i in range(0, len(self.chat_ext_group_ids)):
                    element = self.chat_ext_group_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.chat_ext_group_ids[i] = element.to_alipay_dict()
            if hasattr(self.chat_ext_group_ids, 'to_alipay_dict'):
                params['chat_ext_group_ids'] = self.chat_ext_group_ids.to_alipay_dict()
            else:
                params['chat_ext_group_ids'] = self.chat_ext_group_ids
        if self.chat_group_ids:
            if isinstance(self.chat_group_ids, list):
                for i in range(0, len(self.chat_group_ids)):
                    element = self.chat_group_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.chat_group_ids[i] = element.to_alipay_dict()
            if hasattr(self.chat_group_ids, 'to_alipay_dict'):
                params['chat_group_ids'] = self.chat_group_ids.to_alipay_dict()
            else:
                params['chat_group_ids'] = self.chat_group_ids
        if self.chat_level_ids:
            if isinstance(self.chat_level_ids, list):
                for i in range(0, len(self.chat_level_ids)):
                    element = self.chat_level_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.chat_level_ids[i] = element.to_alipay_dict()
            if hasattr(self.chat_level_ids, 'to_alipay_dict'):
                params['chat_level_ids'] = self.chat_level_ids.to_alipay_dict()
            else:
                params['chat_level_ids'] = self.chat_level_ids
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.hotline_group_ids:
            if isinstance(self.hotline_group_ids, list):
                for i in range(0, len(self.hotline_group_ids)):
                    element = self.hotline_group_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.hotline_group_ids[i] = element.to_alipay_dict()
            if hasattr(self.hotline_group_ids, 'to_alipay_dict'):
                params['hotline_group_ids'] = self.hotline_group_ids.to_alipay_dict()
            else:
                params['hotline_group_ids'] = self.hotline_group_ids
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.real_name:
            if hasattr(self.real_name, 'to_alipay_dict'):
                params['real_name'] = self.real_name.to_alipay_dict()
            else:
                params['real_name'] = self.real_name
        if self.role_ids:
            if isinstance(self.role_ids, list):
                for i in range(0, len(self.role_ids)):
                    element = self.role_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.role_ids[i] = element.to_alipay_dict()
            if hasattr(self.role_ids, 'to_alipay_dict'):
                params['role_ids'] = self.role_ids.to_alipay_dict()
            else:
                params['role_ids'] = self.role_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCcmAgentQueryModel()
        if 'answering_mode' in d:
            o.answering_mode = d['answering_mode']
        if 'ccs_instance_id' in d:
            o.ccs_instance_id = d['ccs_instance_id']
        if 'chat_ext_group_ids' in d:
            o.chat_ext_group_ids = d['chat_ext_group_ids']
        if 'chat_group_ids' in d:
            o.chat_group_ids = d['chat_group_ids']
        if 'chat_level_ids' in d:
            o.chat_level_ids = d['chat_level_ids']
        if 'email' in d:
            o.email = d['email']
        if 'hotline_group_ids' in d:
            o.hotline_group_ids = d['hotline_group_ids']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'real_name' in d:
            o.real_name = d['real_name']
        if 'role_ids' in d:
            o.role_ids = d['role_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankFinanceYulibaoCapitalRansomResponse(AlipayResponse):

    def __init__(self):
        super(MybankFinanceYulibaoCapitalRansomResponse, self).__init__()
        self._inner_biz_no = None
        self._remark = None
        self._trans_result = None

    @property
    def inner_biz_no(self):
        return self._inner_biz_no

    @inner_biz_no.setter
    def inner_biz_no(self, value):
        self._inner_biz_no = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def trans_result(self):
        return self._trans_result

    @trans_result.setter
    def trans_result(self, value):
        self._trans_result = value

    def parse_response_content(self, response_content):
        response = super(MybankFinanceYulibaoCapitalRansomResponse, self).parse_response_content(response_content)
        if 'inner_biz_no' in response:
            self.inner_biz_no = response['inner_biz_no']
        if 'remark' in response:
            self.remark = response['remark']
        if 'trans_result' in response:
            self.trans_result = response['trans_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantOrderConsumerQueryModel(object):

    def __init__(self):
        self._biz_no = None
        self._buyer_id = None
        self._order_id = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantOrderConsumerQueryModel()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'order_id' in d:
            o.order_id = d['order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenEchoSendModel(object):

    def __init__(self):
        self._city = None
        self._name = None

    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenEchoSendModel()
        if 'city' in d:
            o.city = d['city']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class AlipayPcreditLoanCollateralOperationSyncRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._apply_no = None
        self._biz_ext_info = None
        self._memo = None
        self._operated_time = None
        self._operated_type = None
        self._operator = None
        self._out_request_no = None
        self._attachment = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def apply_no(self):
        return self._apply_no

    @apply_no.setter
    def apply_no(self, value):
        self._apply_no = value
    @property
    def biz_ext_info(self):
        return self._biz_ext_info

    @biz_ext_info.setter
    def biz_ext_info(self, value):
        self._biz_ext_info = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operated_time(self):
        return self._operated_time

    @operated_time.setter
    def operated_time(self, value):
        self._operated_time = value
    @property
    def operated_type(self):
        return self._operated_type

    @operated_type.setter
    def operated_type(self, value):
        self._operated_type = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value

    @property
    def attachment(self):
        return self._attachment

    @attachment.setter
    def attachment(self, value):
        if not isinstance(value, FileItem):
            return
        self._attachment = value

    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'alipay.pcredit.loan.collateral.operation.sync'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.apply_no:
            if hasattr(self.apply_no, 'to_alipay_dict'):
                params['apply_no'] = json.dumps(obj=self.apply_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['apply_no'] = self.apply_no
        if self.biz_ext_info:
            if hasattr(self.biz_ext_info, 'to_alipay_dict'):
                params['biz_ext_info'] = json.dumps(obj=self.biz_ext_info.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['biz_ext_info'] = self.biz_ext_info
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = json.dumps(obj=self.memo.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['memo'] = self.memo
        if self.operated_time:
            if hasattr(self.operated_time, 'to_alipay_dict'):
                params['operated_time'] = json.dumps(obj=self.operated_time.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['operated_time'] = self.operated_time
        if self.operated_type:
            if hasattr(self.operated_type, 'to_alipay_dict'):
                params['operated_type'] = json.dumps(obj=self.operated_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['operated_type'] = self.operated_type
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = json.dumps(obj=self.operator.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['operator'] = self.operator
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = json.dumps(obj=self.out_request_no.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['out_request_no'] = self.out_request_no
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        if self.attachment:
            multipart_params['attachment'] = self.attachment
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditContractPrincipalQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditContractPrincipalQueryResponse, self).__init__()
        self._need_auth = None
        self._url = None

    @property
    def need_auth(self):
        return self._need_auth

    @need_auth.setter
    def need_auth(self, value):
        self._need_auth = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditContractPrincipalQueryResponse, self).parse_response_content(response_content)
        if 'need_auth' in response:
            self.need_auth = response['need_auth']
        if 'url' in response:
            self.url = response['url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CraftsmanWorkOpenModel import CraftsmanWorkOpenModel


class KoubeiCraftsmanDataWorkBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCraftsmanDataWorkBatchqueryResponse, self).__init__()
        self._current_page_no = None
        self._page_size = None
        self._total_page_no = None
        self._total_works = None
        self._works = None

    @property
    def current_page_no(self):
        return self._current_page_no

    @current_page_no.setter
    def current_page_no(self, value):
        self._current_page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_page_no(self):
        return self._total_page_no

    @total_page_no.setter
    def total_page_no(self, value):
        self._total_page_no = value
    @property
    def total_works(self):
        return self._total_works

    @total_works.setter
    def total_works(self, value):
        self._total_works = value
    @property
    def works(self):
        return self._works

    @works.setter
    def works(self, value):
        if isinstance(value, list):
            self._works = list()
            for i in value:
                if isinstance(i, CraftsmanWorkOpenModel):
                    self._works.append(i)
                else:
                    self._works.append(CraftsmanWorkOpenModel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiCraftsmanDataWorkBatchqueryResponse, self).parse_response_content(response_content)
        if 'current_page_no' in response:
            self.current_page_no = response['current_page_no']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_page_no' in response:
            self.total_page_no = response['total_page_no']
        if 'total_works' in response:
            self.total_works = response['total_works']
        if 'works' in response:
            self.works = response['works']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.WitnessPrincipalDTO import WitnessPrincipalDTO
from alipay.aop.api.domain.WitnessPrincipalDTO import WitnessPrincipalDTO


class PaymentClauseDetailDTO(object):

    def __init__(self):
        self._amount = None
        self._memo = None
        self._trans_in_principal = None
        self._trans_out_principal = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def trans_in_principal(self):
        return self._trans_in_principal

    @trans_in_principal.setter
    def trans_in_principal(self, value):
        if isinstance(value, WitnessPrincipalDTO):
            self._trans_in_principal = value
        else:
            self._trans_in_principal = WitnessPrincipalDTO.from_alipay_dict(value)
    @property
    def trans_out_principal(self):
        return self._trans_out_principal

    @trans_out_principal.setter
    def trans_out_principal(self, value):
        if isinstance(value, WitnessPrincipalDTO):
            self._trans_out_principal = value
        else:
            self._trans_out_principal = WitnessPrincipalDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.trans_in_principal:
            if hasattr(self.trans_in_principal, 'to_alipay_dict'):
                params['trans_in_principal'] = self.trans_in_principal.to_alipay_dict()
            else:
                params['trans_in_principal'] = self.trans_in_principal
        if self.trans_out_principal:
            if hasattr(self.trans_out_principal, 'to_alipay_dict'):
                params['trans_out_principal'] = self.trans_out_principal.to_alipay_dict()
            else:
                params['trans_out_principal'] = self.trans_out_principal
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentClauseDetailDTO()
        if 'amount' in d:
            o.amount = d['amount']
        if 'memo' in d:
            o.memo = d['memo']
        if 'trans_in_principal' in d:
            o.trans_in_principal = d['trans_in_principal']
        if 'trans_out_principal' in d:
            o.trans_out_principal = d['trans_out_principal']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityRiskHufuAuthCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskHufuAuthCreateResponse, self).__init__()
        self._info = None
        self._serial = None
        self._token = None

    @property
    def info(self):
        return self._info

    @info.setter
    def info(self, value):
        self._info = value
    @property
    def serial(self):
        return self._serial

    @serial.setter
    def serial(self, value):
        self._serial = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskHufuAuthCreateResponse, self).parse_response_content(response_content)
        if 'info' in response:
            self.info = response['info']
        if 'serial' in response:
            self.serial = response['serial']
        if 'token' in response:
            self.token = response['token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchBoxAppInfo(object):

    def __init__(self):
        self._app_name = None
        self._app_type = None
        self._relate_appid = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_type(self):
        return self._app_type

    @app_type.setter
    def app_type(self, value):
        self._app_type = value
    @property
    def relate_appid(self):
        return self._relate_appid

    @relate_appid.setter
    def relate_appid(self, value):
        self._relate_appid = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_type:
            if hasattr(self.app_type, 'to_alipay_dict'):
                params['app_type'] = self.app_type.to_alipay_dict()
            else:
                params['app_type'] = self.app_type
        if self.relate_appid:
            if hasattr(self.relate_appid, 'to_alipay_dict'):
                params['relate_appid'] = self.relate_appid.to_alipay_dict()
            else:
                params['relate_appid'] = self.relate_appid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchBoxAppInfo()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_type' in d:
            o.app_type = d['app_type']
        if 'relate_appid' in d:
            o.relate_appid = d['relate_appid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AuthorizeInfo import AuthorizeInfo
from alipay.aop.api.domain.BrandRegistrationInfo import BrandRegistrationInfo


class AlipayOpenMiniMiniappBrandSubmitModel(object):

    def __init__(self):
        self._apply_type = None
        self._authorize_info = None
        self._brand_id = None
        self._brand_name = None
        self._brand_registration_info = None
        self._id_materials = None

    @property
    def apply_type(self):
        return self._apply_type

    @apply_type.setter
    def apply_type(self, value):
        self._apply_type = value
    @property
    def authorize_info(self):
        return self._authorize_info

    @authorize_info.setter
    def authorize_info(self, value):
        if isinstance(value, AuthorizeInfo):
            self._authorize_info = value
        else:
            self._authorize_info = AuthorizeInfo.from_alipay_dict(value)
    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def brand_registration_info(self):
        return self._brand_registration_info

    @brand_registration_info.setter
    def brand_registration_info(self, value):
        if isinstance(value, BrandRegistrationInfo):
            self._brand_registration_info = value
        else:
            self._brand_registration_info = BrandRegistrationInfo.from_alipay_dict(value)
    @property
    def id_materials(self):
        return self._id_materials

    @id_materials.setter
    def id_materials(self, value):
        if isinstance(value, list):
            self._id_materials = list()
            for i in value:
                self._id_materials.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.apply_type:
            if hasattr(self.apply_type, 'to_alipay_dict'):
                params['apply_type'] = self.apply_type.to_alipay_dict()
            else:
                params['apply_type'] = self.apply_type
        if self.authorize_info:
            if hasattr(self.authorize_info, 'to_alipay_dict'):
                params['authorize_info'] = self.authorize_info.to_alipay_dict()
            else:
                params['authorize_info'] = self.authorize_info
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.brand_registration_info:
            if hasattr(self.brand_registration_info, 'to_alipay_dict'):
                params['brand_registration_info'] = self.brand_registration_info.to_alipay_dict()
            else:
                params['brand_registration_info'] = self.brand_registration_info
        if self.id_materials:
            if isinstance(self.id_materials, list):
                for i in range(0, len(self.id_materials)):
                    element = self.id_materials[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.id_materials[i] = element.to_alipay_dict()
            if hasattr(self.id_materials, 'to_alipay_dict'):
                params['id_materials'] = self.id_materials.to_alipay_dict()
            else:
                params['id_materials'] = self.id_materials
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniMiniappBrandSubmitModel()
        if 'apply_type' in d:
            o.apply_type = d['apply_type']
        if 'authorize_info' in d:
            o.authorize_info = d['authorize_info']
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'brand_registration_info' in d:
            o.brand_registration_info = d['brand_registration_info']
        if 'id_materials' in d:
            o.id_materials = d['id_materials']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsPerson import InsPerson


class AlipayInsSceneProductAccessApplyModel(object):

    def __init__(self):
        self._applicant = None
        self._out_biz_no = None
        self._prod_code = None
        self._source = None

    @property
    def applicant(self):
        return self._applicant

    @applicant.setter
    def applicant(self, value):
        if isinstance(value, InsPerson):
            self._applicant = value
        else:
            self._applicant = InsPerson.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value


    def to_alipay_dict(self):
        params = dict()
        if self.applicant:
            if hasattr(self.applicant, 'to_alipay_dict'):
                params['applicant'] = self.applicant.to_alipay_dict()
            else:
                params['applicant'] = self.applicant
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneProductAccessApplyModel()
        if 'applicant' in d:
            o.applicant = d['applicant']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        if 'source' in d:
            o.source = d['source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SubButton(object):

    def __init__(self):
        self._action_param = None
        self._action_type = None
        self._icon = None
        self._name = None

    @property
    def action_param(self):
        return self._action_param

    @action_param.setter
    def action_param(self, value):
        self._action_param = value
    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_param:
            if hasattr(self.action_param, 'to_alipay_dict'):
                params['action_param'] = self.action_param.to_alipay_dict()
            else:
                params['action_param'] = self.action_param
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SubButton()
        if 'action_param' in d:
            o.action_param = d['action_param']
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'icon' in d:
            o.icon = d['icon']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RecommendAccountDTO(object):

    def __init__(self):
        self._alipay_account = None
        self._user_name = None

    @property
    def alipay_account(self):
        return self._alipay_account

    @alipay_account.setter
    def alipay_account(self, value):
        self._alipay_account = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_account:
            if hasattr(self.alipay_account, 'to_alipay_dict'):
                params['alipay_account'] = self.alipay_account.to_alipay_dict()
            else:
                params['alipay_account'] = self.alipay_account
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RecommendAccountDTO()
        if 'alipay_account' in d:
            o.alipay_account = d['alipay_account']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMobilePublicMessageCustomSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMobilePublicMessageCustomSendResponse, self).__init__()
        self._code = None
        self._msg = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value

    def parse_response_content(self, response_content):
        response = super(AlipayMobilePublicMessageCustomSendResponse, self).parse_response_content(response_content)
        if 'code' in response:
            self.code = response['code']
        if 'msg' in response:
            self.msg = response['msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ConsumeRecord import ConsumeRecord


class AlipayUserBillDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserBillDetailQueryResponse, self).__init__()
        self._consume_record = None

    @property
    def consume_record(self):
        return self._consume_record

    @consume_record.setter
    def consume_record(self, value):
        if isinstance(value, ConsumeRecord):
            self._consume_record = value
        else:
            self._consume_record = ConsumeRecord.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayUserBillDetailQueryResponse, self).parse_response_content(response_content)
        if 'consume_record' in response:
            self.consume_record = response['consume_record']
